@@ -452,7 +452,7 @@ class Circuit:
         project_name: str,
         generate_pcb: bool = True,
         force_regenerate: bool = False,
-        placement_algorithm: str = "connection_aware",
+        placement_algorithm: str = "connection_centric",
         draw_bounding_boxes: bool = False,
         generate_ratsnest: bool = True,
     ) -> None:
@@ -467,7 +467,7 @@ class Circuit:
             project_name: Name of the KiCad project and directory to create
             generate_pcb: Whether to generate PCB in addition to schematic (default: True)
             force_regenerate: Force regeneration of existing files, losing manual edits (default: False)
-            placement_algorithm: Component placement algorithm to use (default: "connection_aware")
+            placement_algorithm: Component placement algorithm to use (default: "connection_centric")
             draw_bounding_boxes: Whether to draw visual bounding boxes around components (default: False)
             generate_ratsnest: Whether to generate ratsnest connections in PCB (default: True)
 
@@ -517,7 +517,8 @@ class Circuit:
                 # Legacy system handles placement, modern API handles file writing via write_schematic_file
                 result = generator.generate_project(
                     json_file=temp_json_path,
-                    schematic_placement=placement_algorithm,
+                    placement_algorithm=placement_algorithm,  # PCB placement algorithm  
+                    schematic_placement="sequential",  # Use simple sequential for schematic
                     generate_pcb=generate_pcb,
                     force_regenerate=force_regenerate,
                     draw_bounding_boxes=draw_bounding_boxes,
