@@ -15,7 +15,7 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
 from circuit_synth.core.circuit import Circuit
-from circuit_synth.kicad.core.s_expression import SExpressionParser
+import kicad_sch_api as ksa
 from circuit_synth.pcb import PCBBoard
 
 # Removed duplicate PCB API imports - using single implementation
@@ -275,8 +275,7 @@ class PCBGenerator:
                     # Reset component positions before retry
                     if retry_count > 0:
                         for fp in pcb.footprints.values():
-                            fp.position.x = 50
-                            fp.position.y = 50
+                            fp.position = Point(50, 50)
 
                     # Debug: List components before placement
                     if retry_count == 0:
@@ -304,11 +303,6 @@ class PCBGenerator:
                             iterations_per_level=150,  # More iterations
                         )
                     else:
-                        logger.error(f"🔥🔥🔥 PCB GENERATOR: About to call auto_place_components 🔥🔥🔥")
-                        logger.error(f"🔥 PCB GENERATOR: placement_algorithm = '{placement_algorithm}'")
-                        logger.error(f"🔥 PCB GENERATOR: board size = {current_width}x{current_height}")
-                        logger.error(f"🔥 PCB GENERATOR: component count = {len(pcb.footprints)}")
-                        
                         result = pcb.auto_place_components(
                             algorithm=placement_algorithm,
                             component_spacing=component_spacing,
@@ -324,12 +318,6 @@ class PCBGenerator:
                                 else None
                             ),
                         )
-                        
-                        logger.error(f"🔥🔥🔥 PCB GENERATOR: auto_place_components RETURNED 🔥🔥🔥")
-                        logger.error(f"🔥 PCB GENERATOR: result = {result}")
-                        logger.error(f"🔥 PCB GENERATOR: Component positions after auto_place_components:")
-                        for ref, footprint in pcb.footprints.items():
-                            logger.error(f"🔥   {ref}: ({footprint.position.x}, {footprint.position.y})")
 
                     # If we get here, placement was successful
                     placement_successful = True
@@ -338,23 +326,13 @@ class PCBGenerator:
                     )
 
                     # Calculate actual board size needed based on placement
-                    logger.error(f"🔥🔥🔥 PCB GENERATOR: Starting bounding box calculation 🔥🔥🔥")
-                    logger.error(f"🔥 PCB GENERATOR: placement_algorithm = '{placement_algorithm}'")
-                    
-                    # Simplified placement calculation
                     def calculate_placement_bbox(footprints, margin=10.0):
                         if not footprints:
-                            logger.error(f"🔥 BBOX: No footprints, returning default bbox")
                             return -margin, -margin, margin, margin
-                        # Simple bounding box calculation
-                        logger.error(f"🔥 BBOX: Calculating bbox for {len(footprints)} footprints")
-                        for fp in footprints[:3]:  # Log first 3
-                            logger.error(f"🔥 BBOX:   {fp.reference}: ({fp.position.x}, {fp.position.y})")
                         min_x = min(fp.position.x for fp in footprints) - margin
                         min_y = min(fp.position.y for fp in footprints) - margin
                         max_x = max(fp.position.x for fp in footprints) + margin
                         max_y = max(fp.position.y for fp in footprints) + margin
-                        logger.error(f"🔥 BBOX: Calculated bbox: ({min_x}, {min_y}) to ({max_x}, {max_y})")
                         return min_x, min_y, max_x, max_y
 
                     footprints = list(pcb.footprints.values())
@@ -365,29 +343,20 @@ class PCBGenerator:
                     # Round up to nearest 5mm for cleaner dimensions
                     actual_width = ((max_x - min_x + 4) // 5) * 5
                     actual_height = ((max_y - min_y + 4) // 5) * 5
-                    logger.error(f"🔥 PCB GENERATOR: Calculated board dimensions: {actual_width}x{actual_height}mm")
 
                     # Update board outline to actual size needed (skip for external placement)
                     if placement_algorithm != "external":
-                        logger.error(f"🔥 PCB GENERATOR: NOT external - updating board outline to {actual_width}x{actual_height}")
                         pcb.set_board_outline_rect(0, 0, actual_width, actual_height)
                         logger.debug(
                             f"✓ Adjusted board size to actual needs: {actual_width}x{actual_height}mm"
                         )
                     else:
-                        logger.error(f"🔥 PCB GENERATOR: EXTERNAL PLACEMENT - preserving cutout rectangle")
                         logger.debug("Skipping board outline recalculation for external placement to preserve cutout")
 
                     # Debug: Check result and list components after placement
-                    logger.error(f"🔥🔥🔥 PCB GENERATOR: Final placement check 🔥🔥🔥")
                     logger.debug(f"Placement result: {result}")
                     footprints_after = pcb.list_footprints()
                     logger.debug(f"Components after placement: {len(footprints_after)}")
-                    logger.error(f"🔥 PCB GENERATOR: Components after ALL processing:")
-                    for ref, footprint_lib, x, y in footprints_after:  # Show ALL components
-                        logger.error(f"🔥   {ref} at ({x}, {y}) - {footprint_lib}")
-                    
-                    logger.error(f"🔥🔥🔥 PCB GENERATOR: About to write PCB file 🔥🔥🔥")
 
                 except ValueError as e:
                     if "Could not find valid position" in str(e):
@@ -441,7 +410,7 @@ class PCBGenerator:
 
             # Save PCB file
             pcb.save(self.pcb_path)
-            logger.debug(f"PCB file saved to: {self.pcb_path}")
+            logger.info(f"✓ PCB file saved to: {self.pcb_path}")
 
             # Generate ratsnest connections if requested (AFTER PCB save)
             if generate_ratsnest:
@@ -482,8 +451,7 @@ class PCBGenerator:
         for sch_file in sch_files:
             try:
                 logger.debug(f"Reading schematic: {sch_file}")
-                parser = SExpressionParser()
-                schematic = parser.parse_file(str(sch_file))
+                schematic = ksa.Schematic.load(str(sch_file))
 
                 # Get components from this schematic
                 for comp in schematic.components:
@@ -630,8 +598,7 @@ class PCBGenerator:
 
             for sch_file in sch_files:
                 try:
-                    parser = SExpressionParser()
-                    schematic = parser.parse_file(str(sch_file))
+                    schematic = ksa.Schematic.load(str(sch_file))
 
                     # Extract nets from schematic
                     for net in schematic.nets:
