@@ -55,7 +55,8 @@ class LLMPlacementManager:
 # Use optimized symbol cache from core.component for better performance
 from circuit_synth.core.component import SymbolLibCache
 from circuit_synth.kicad.canonical import CanonicalCircuit, CircuitMatcher
-from circuit_synth.kicad.core.s_expression import SExpressionParser
+import kicad_sch_api as ksa
+from kicad_sch_api.core.types import Point
 from circuit_synth.kicad.kicad_symbol_cache import SymbolLibCache
 
 from .symbol_geometry import SymbolBoundingBoxCalculator
@@ -1143,9 +1144,8 @@ class SchematicGenerator:
             if existing_sch_path.exists():
                 logger.info(f"Found existing schematic file: {existing_sch_path}")
                 try:
-                    # Read existing schematic using S-expression parser
-                    parser = SExpressionParser()
-                    schematic = parser.parse_file(str(existing_sch_path))
+                    # Read existing schematic using kicad-sch-api
+                    schematic = ksa.Schematic.load(str(existing_sch_path))
                     existing_components = schematic.components
                     logger.info(
                         f"Found {len(existing_components)} components in existing schematic"
@@ -1274,8 +1274,7 @@ class SchematicGenerator:
                 if comp.reference in existing_positions:
                     # Use existing position
                     x, y = existing_positions[comp.reference]
-                    comp.position.x = x
-                    comp.position.y = y
+                    comp.position = Point(x, y)
                     logger.debug(
                         f"Using preserved position for {comp.reference}: ({x}, {y})"
                     )
@@ -1342,8 +1341,7 @@ class SchematicGenerator:
                     else:
                         x, y = cm.place_symbol(comp_width, comp_height)
 
-                    comp.position.x = x
-                    comp.position.y = y
+                    comp.position = Point(x, y)
                     logger.debug(
                         f"Placed new component {comp.reference} at: ({x}, {y})"
                     )
